import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

class WebviewAuth extends StatefulWidget {
  String authUrl;
  Function onCompletion;

  WebviewAuth({this.authUrl, this.onCompletion});

  @override
  State<StatefulWidget> createState() {
    return _WebviewAuthState();
  }
}

class _WebviewAuthState extends State<WebviewAuth> {
  WebViewController _controller;

  @override
  Widget build(BuildContext context) {
    final webview = WebView(
      initialUrl: widget.authUrl,
      javascriptMode: JavascriptMode.unrestricted,
      initialMediaPlaybackPolicy: AutoMediaPlaybackPolicy.always_allow,
      onWebViewCreated: (WebViewController webViewController) {
        _controller = webViewController;
      },
      navigationDelegate: (req) {
        return handleNavigation(req, context);
      },
      debuggingEnabled: true,
    );

    return Scaffold(
      appBar: AppBar(
        title: Text('Webview Auth'),
      ),
      body: webview,
    );
  }

  NavigationDecision handleNavigation(NavigationRequest req, BuildContext context) {
    final authResult = parseAuthCallback(req.url);

    if (authResult.accessToken != null) {
      widget.onCompletion(authResult);
    }

    return NavigationDecision.navigate;
  }
}

class AuthResult {
  String error;
  String accessToken;

  AuthResult({this.error = null, this.accessToken});
}

AuthResult parseAuthCallback(String url) {
  final urlData = Uri.parse(url);
  final fragment = urlData.fragment;

  if (urlData.path != '/bitmio_callback') {
    return AuthResult();
  }

  if (fragment == null) {
    return AuthResult();
  }

  final dummyUrl = Uri.parse('test?$fragment');
  final accessToken = dummyUrl.queryParameters['access_token'];
  final error = dummyUrl.queryParameters['error'];

  return AuthResult(accessToken: accessToken, error: error);
}